@@ -13,9 +13,9 @@ pub mod surf {
     pub use ajars_surf::*;
 }
 
-#[cfg(feature = "web_sys")]
-pub mod web_sys {
-    pub use ajars_web_sys::*;
+#[cfg(feature = "web")]
+pub mod web {
+    pub use ajars_web::*;
 }
 
 pub use ajars_core::*;
